@@ -6,19 +6,15 @@
 __version__ = '0.1.0'
 
 import logging
-import os
 from collections import defaultdict
 
 patched_modules = defaultdict(lambda: [])
 
 from baseten.baseten_deployed_model import BasetenDeployedModel  # noqa: E402
 from baseten.baseten_deployed_model import install_requirements, requirements_status  # noqa: E402, F401
-from baseten.common.external_connections import add_external_connection, external_connections  # noqa: E402, F401
-from baseten.common.model_deployer import deploy_model_object  # noqa: E402
-from baseten.common.core import BASETEN_CONFIG_DIRECTORY  # noqa: E402
+from baseten.common.model_deployer import deploy_custom_model, deploy_model_object  # noqa: E402
 from baseten.common.util import setup_logger  # noqa: E402
 from baseten.common import settings  # noqa: E402
-from baseten.workflows import BasetenWorkflow  # noqa: E402
 
 
 logger = logging.getLogger(__name__)
@@ -30,6 +26,7 @@ logger.debug(f'Starting the client with the server URL set to {settings.API_URL_
 # The Baseten model ID that either a) the user initialized baseten with, or b) was created when deploying a model.
 working_model_id = None
 deploy = deploy_model_object  # This allows the user to call baseten.deploy(model)
+deploy_custom = deploy_custom_model  # This allows the user to call baseten.deploy_custom(...)
 
 
 def set_log_level(level):
@@ -46,9 +43,6 @@ def init(baseten_model_id=None):
     global working_model_id
     working_model_id = baseten_model_id
 
-    if not os.path.exists(BASETEN_CONFIG_DIRECTORY):
-        os.makedirs(BASETEN_CONFIG_DIRECTORY)
-
 
 def deployed_model_id(model_id: str) -> BasetenDeployedModel:
     """Returns a BasetenDeployedModel object for interacting with the model model_id.
@@ -74,13 +68,11 @@ def deployed_model_version_id(model_version_id: str) -> BasetenDeployedModel:
     return BasetenDeployedModel(model_version_id=model_version_id)
 
 
-def workflow_by_id(workflow_id: str) -> BasetenWorkflow:
-    """Returns a BasetenWorkflow object for interacting with the workflow.
+def login(api_key: str):
+    """Set the API key for the client.
 
     Args:
-        workflow_id (str)
-
-    Returns:
-        BasetenWorkflow
+        api_key (str)
     """
-    return BasetenWorkflow(workflow_id=workflow_id)
+    settings.set_config_value('api', 'api_key', api_key)
+    logger.info('API key set.')
